@@ -28,6 +28,7 @@ from .literals import (
     ExpirationModelTypeType,
     GrantOperationType,
     KeyManagerTypeType,
+    KeySpecType,
     KeyStateType,
     KeyUsageTypeType,
     MessageTypeType,
@@ -237,6 +238,7 @@ CreateKeyRequestRequestTypeDef = TypedDict(
         "Description": str,
         "KeyUsage": KeyUsageTypeType,
         "CustomerMasterKeySpec": CustomerMasterKeySpecType,
+        "KeySpec": KeySpecType,
         "Origin": OriginTypeType,
         "CustomKeyStoreId": str,
         "BypassPolicyLockoutSafetyCheck": bool,
@@ -676,6 +678,7 @@ GetPublicKeyResponseTypeDef = TypedDict(
         "KeyId": str,
         "PublicKey": bytes,
         "CustomerMasterKeySpec": CustomerMasterKeySpecType,
+        "KeySpec": KeySpecType,
         "KeyUsage": KeyUsageTypeType,
         "EncryptionAlgorithms": List[EncryptionAlgorithmSpecType],
         "SigningAlgorithms": List[SigningAlgorithmSpecType],
@@ -765,6 +768,7 @@ _OptionalKeyMetadataTypeDef = TypedDict(
         "ExpirationModel": ExpirationModelTypeType,
         "KeyManager": KeyManagerTypeType,
         "CustomerMasterKeySpec": CustomerMasterKeySpecType,
+        "KeySpec": KeySpecType,
         "EncryptionAlgorithms": List[EncryptionAlgorithmSpecType],
         "SigningAlgorithms": List[SigningAlgorithmSpecType],
         "MultiRegion": bool,
